.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   installation
   modules
   usage
   contributing
   authors
   history

Feedback
========

If you have any suggestions or questions about **dovpanda** feel free to email me
at deanla@gmail.com.

If you encounter any errors or problems with **dovpanda**, please let me know!
Open an Issue at the GitHub http://github.com/dovpanda-dev/dovpanda main repository.
